# ScippNeutron

<span style="font-size:1.2em;font-style:italic;color:#5a5a5a">
  Neutron scattering tools for Data Reduction powered by Scipp.
  </br></br>
</span>

:::{include} user-guide/installation.md
:heading-offset: 1
:::

## Get in touch

- If you have questions that are not answered by these documentation pages, ask on [GitHub discussions](https://github.com/orgs/scipp/discussions). Please include a self-contained reproducible example if possible.
- Report bugs (including unclear, missing, or wrong documentation!), suggest features or view the source code [on GitHub](https://github.com/scipp/scippneutron).

```{toctree}
---
hidden:
---

user-guide/index
api-reference/index
tutorials/index
developer/index
about/index
```
